==> haskell-io-streams-1.5.2.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 io-streams
version:              1.5.2.1
visibility:           public
id:                   io-streams-1.5.2.1-HmHtmHJvRuNG6y2xRFUWVy
key:                  io-streams-1.5.2.1-HmHtmHJvRuNG6y2xRFUWVy
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             Simple, composable, and easy-to-use stream I/O
description:
    /Overview/

    The io-streams library contains simple and easy-to-use primitives for I/O
    using streams. Most users will want to import the top-level convenience
    module "System.IO.Streams", which re-exports most of the library:

    @
    import           System.IO.Streams (InputStream, OutputStream)
    import qualified System.IO.Streams as Streams
    @

    For first-time users, @io-streams@ comes with an included tutorial, which can
    be found in the "System.IO.Streams.Tutorial" module.

    /Features/

    The @io-streams@ user API has two basic types: @InputStream a@ and
    @OutputStream a@, and three fundamental I/O primitives:

    @
    \-\- read an item from an input stream
    Streams.read :: InputStream a -> IO (Maybe a)

    \-\- push an item back to an input stream
    Streams.unRead :: a -> InputStream a -> IO ()

    \-\- write to an output stream
    Streams.write :: Maybe a -> OutputStream a -> IO ()
    @

    Streams can be transformed by composition and hooked together with provided combinators:

    @
    ghci> Streams.fromList [1,2,3::Int] >>= Streams.map (*10) >>= Streams.toList
    [10,20,30]
    @

    Stream composition leaves the original stream accessible:

    @
    ghci> input \<- Streams.fromByteString \"long string\"
    ghci> wrapped \<- Streams.takeBytes 4 input
    ghci> Streams.read wrapped
    Just \"long\"
    ghci> Streams.read wrapped
    Nothing
    ghci> Streams.read input
    Just \" string\"
    @

    Simple types and operations in the IO monad mean straightforward and simple
    exception handling and resource cleanup using Haskell standard library
    facilities like '\''Control.Exception.bracket'\''.

    @io-streams@ comes with:

    * functions to use files, handles, concurrent channels, sockets, lists,
    vectors, and more as streams.

    * a variety of combinators for wrapping and transforming streams, including
    compression and decompression using zlib, controlling precisely how many
    bytes are read from or written to a stream, buffering output using
    bytestring builders, folds, maps, filters, zips, etc.

    * support for parsing from streams using @attoparsec@.

    * support for spawning processes and communicating with them using streams.

category:             Data, Network, IO-Streams
abi:                  8f18a2c92f2d688a913157d74780cb82
exposed:              True
exposed-modules:
    System.IO.Streams System.IO.Streams.Attoparsec
    System.IO.Streams.Attoparsec.ByteString
    System.IO.Streams.Attoparsec.Text System.IO.Streams.Builder
    System.IO.Streams.ByteString System.IO.Streams.Combinators
    System.IO.Streams.Concurrent System.IO.Streams.Core
    System.IO.Streams.Debug System.IO.Streams.File
    System.IO.Streams.Handle System.IO.Streams.Internal
    System.IO.Streams.List System.IO.Streams.Network
    System.IO.Streams.Process System.IO.Streams.Text
    System.IO.Streams.Tutorial System.IO.Streams.Vector
    System.IO.Streams.Zlib

hidden-modules:
    System.IO.Streams.Internal.Attoparsec
    System.IO.Streams.Internal.Search
    System.IO.Streams.Internal.Network

import-dirs:          /usr/lib/ghc-8.10.4/site-local/io-streams-1.5.2.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/io-streams-1.5.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/io-streams-1.5.2.1
hs-libraries:         HSio-streams-1.5.2.1-HmHtmHJvRuNG6y2xRFUWVy
depends:
    attoparsec-0.14.1-94M7XwbxYJLFvYthp17dR base-4.14.1.0
    bytestring-0.10.12.0 network-3.1.2.1-JWsgyzxIkceBMW0wbRjAeX
    primitive-0.7.1.0-13wN2gQNzg4GPNbXgU7tHl process-1.6.9.0
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    vector-0.12.3.0-HURuJbi2iJT3pZcjBMuHYu
    zlib-bindings-0.1.1.5-4PFUNkdOYOl8zWeRqNkivY

haddock-interfaces:   /usr/share/doc/haskell-io-streams/html/io-streams.haddock
haddock-html:         /usr/share/doc/haskell-io-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-1.5.2.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 io-streams
version:              1.5.2.1
visibility:           public
id:                   io-streams-1.5.2.1-IGMRb3cWIkMHgIxJFzg5ai
key:                  io-streams-1.5.2.1-IGMRb3cWIkMHgIxJFzg5ai
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             Simple, composable, and easy-to-use stream I/O
description:
    /Overview/

    The io-streams library contains simple and easy-to-use primitives for I/O
    using streams. Most users will want to import the top-level convenience
    module "System.IO.Streams", which re-exports most of the library:

    @
    import           System.IO.Streams (InputStream, OutputStream)
    import qualified System.IO.Streams as Streams
    @

    For first-time users, @io-streams@ comes with an included tutorial, which can
    be found in the "System.IO.Streams.Tutorial" module.

    /Features/

    The @io-streams@ user API has two basic types: @InputStream a@ and
    @OutputStream a@, and three fundamental I/O primitives:

    @
    \-\- read an item from an input stream
    Streams.read :: InputStream a -> IO (Maybe a)

    \-\- push an item back to an input stream
    Streams.unRead :: a -> InputStream a -> IO ()

    \-\- write to an output stream
    Streams.write :: Maybe a -> OutputStream a -> IO ()
    @

    Streams can be transformed by composition and hooked together with provided combinators:

    @
    ghci> Streams.fromList [1,2,3::Int] >>= Streams.map (*10) >>= Streams.toList
    [10,20,30]
    @

    Stream composition leaves the original stream accessible:

    @
    ghci> input \<- Streams.fromByteString \"long string\"
    ghci> wrapped \<- Streams.takeBytes 4 input
    ghci> Streams.read wrapped
    Just \"long\"
    ghci> Streams.read wrapped
    Nothing
    ghci> Streams.read input
    Just \" string\"
    @

    Simple types and operations in the IO monad mean straightforward and simple
    exception handling and resource cleanup using Haskell standard library
    facilities like '\''Control.Exception.bracket'\''.

    @io-streams@ comes with:

    * functions to use files, handles, concurrent channels, sockets, lists,
    vectors, and more as streams.

    * a variety of combinators for wrapping and transforming streams, including
    compression and decompression using zlib, controlling precisely how many
    bytes are read from or written to a stream, buffering output using
    bytestring builders, folds, maps, filters, zips, etc.

    * support for parsing from streams using @attoparsec@.

    * support for spawning processes and communicating with them using streams.

category:             Data, Network, IO-Streams
abi:                  83596516bb13e3f2203ed5443b2acae7
exposed:              True
exposed-modules:
    System.IO.Streams System.IO.Streams.Attoparsec
    System.IO.Streams.Attoparsec.ByteString
    System.IO.Streams.Attoparsec.Text System.IO.Streams.Builder
    System.IO.Streams.ByteString System.IO.Streams.Combinators
    System.IO.Streams.Concurrent System.IO.Streams.Core
    System.IO.Streams.Debug System.IO.Streams.File
    System.IO.Streams.Handle System.IO.Streams.Internal
    System.IO.Streams.List System.IO.Streams.Network
    System.IO.Streams.Process System.IO.Streams.Text
    System.IO.Streams.Tutorial System.IO.Streams.Vector
    System.IO.Streams.Zlib

hidden-modules:
    System.IO.Streams.Internal.Attoparsec
    System.IO.Streams.Internal.Search
    System.IO.Streams.Internal.Network

import-dirs:          /usr/lib/ghc-8.10.4/site-local/io-streams-1.5.2.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/io-streams-1.5.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/io-streams-1.5.2.1
hs-libraries:         HSio-streams-1.5.2.1-IGMRb3cWIkMHgIxJFzg5ai
depends:
    attoparsec-0.14.1-C6wGreXaJC9Hw3F0wMqT0I base-4.14.1.0
    bytestring-0.10.12.0 network-3.1.2.1-DsZbGjsE7U23ms8WBrhjnk
    primitive-0.7.1.0-8m0SIkzvpWsEA8CwM92QVI process-1.6.9.0
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    vector-0.12.3.0-FUD0lZOETAI870JKqcsC0A
    zlib-bindings-0.1.1.5-96lLnXGS5Lm8H4uj2Dj0hH

haddock-interfaces:   /usr/share/doc/haskell-io-streams/html/io-streams.haddock
haddock-html:         /usr/share/doc/haskell-io-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
